summaryrefslogtreecommitdiff
path: root/gabble
diff options
context:
space:
mode:
authorJonny Lamb <jonny.lamb@collabora.co.uk>2012-02-01 16:07:25 -0500
committerJonny Lamb <jonny.lamb@collabora.co.uk>2012-02-01 16:07:25 -0500
commitab745cbdead64a313fe3e8859cec5bf7c4382dc9 (patch)
tree024c6049bdae369f8833b02c0c5ed38691bbf419 /gabble
parent1d41beb99b03f828fd204e6e18fa7499360937b9 (diff)
Revert "Merge remote-tracking branch 'siraj/plugin-api-change'"
Diffstat (limited to 'gabble')
-rw-r--r--gabble/plugin.h16
1 files changed, 3 insertions, 13 deletions
diff --git a/gabble/plugin.h b/gabble/plugin.h
index ffb888c29..6da99f136 100644
--- a/gabble/plugin.h
+++ b/gabble/plugin.h
@@ -60,11 +60,6 @@ typedef GPtrArray * (*GabblePluginCreateChannelManagersImpl) (
GabblePlugin *plugin,
TpBaseConnection *connection);
-typedef GabbleSidecar * (*GabblePluginCreateSidecarFinishImpl) (
- GabblePlugin *plugin,
- GAsyncResult *result,
- GError **error);
-
struct _GabblePluginPrivacyListMap {
const gchar *presence_status_name;
const gchar *privacy_list_name;
@@ -86,14 +81,9 @@ struct _GabblePluginInterface {
const gchar * const *sidecar_interfaces;
/**
- * An implementation of gabble_plugin_create_sidecar_async().
- */
- GabblePluginCreateSidecarImpl create_sidecar_async;
-
- /**
- * An implementation of gabble_plugin_create_sidecar_finish().
+ * An implementation of gabble_plugin_create_sidecar().
*/
- GabblePluginCreateSidecarFinishImpl create_sidecar_finish;
+ GabblePluginCreateSidecarImpl create_sidecar;
/**
* The plugin's version, conventionally a "."-separated sequence of
@@ -130,7 +120,7 @@ gboolean gabble_plugin_implements_sidecar (
GabblePlugin *plugin,
const gchar *sidecar_interface);
-void gabble_plugin_create_sidecar_async (
+void gabble_plugin_create_sidecar (
GabblePlugin *plugin,
const gchar *sidecar_interface,
GabbleConnection *connection,